
JSON Operations

A simple module for reading and writing JSON.
Functions:
1. read - returns the value of the JSON file;
2. save - saves the value of a variable in a JSON file.


Простой модуль для чтения и записи JSON-файлов.
1. read - возвращает значение JSON-файла;
2. save - экспортирует значение переменной в JSON-файл.
